| qqlog | R Documentation |
Accepts -\log_{10}(p) values directly as input. This is useful when
the caller has already transformed their p-values, or when higher numerical
precision is required before passing values to the plotting layer. Produces
the same style of plot and uses the same fast pruning algorithm as
qq.
qqlog(log10_pvector, ...)
log10_pvector |
A numeric vector of |
... |
Other arguments passed to |
No return value, called for plotting side effects.
pvec <- stats::runif(1e5)
qqlog(-log10(pvec))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.